Documentation
¶
Index ¶
- Constants
- type APIError
- type Client
- func (c *Client) Active(ctx context.Context, params Params) (*SearchResult, error)
- func (c *Client) Aged(ctx context.Context, params Params) (*SearchResult, error)
- func (c *Client) CTCerts(ctx context.Context, params Params) (*ListResult, error)
- func (c *Client) CTSearch(ctx context.Context, keyword string, params Params) (*ListResult, error)
- func (c *Client) CTSubdomains(ctx context.Context, domain string, params Params) (*ListResult, error)
- func (c *Client) DNS(ctx context.Context, domain string) (map[string]any, error)
- func (c *Client) Deleted(ctx context.Context, params Params) (*SearchResult, error)
- func (c *Client) Expired(ctx context.Context, params Params) (*SearchResult, error)
- func (c *Client) Export(ctx context.Context, resource string, params Params) ([]byte, error)
- func (c *Client) Health(ctx context.Context) (map[string]any, error)
- func (c *Client) IPLookup(ctx context.Context, query string) (map[string]any, error)
- func (c *Client) KeywordTrends(ctx context.Context, trendType string, params Params) ([]map[string]any, error)
- func (c *Client) Market(ctx context.Context, params Params) (*SearchResult, error)
- func (c *Client) MonitorChanges(ctx context.Context, params Params) (*ListResult, error)
- func (c *Client) NRDs(ctx context.Context, params Params) (*SearchResult, error)
- func (c *Client) NRDsDownload(ctx context.Context, params Params) ([]byte, error)
- func (c *Client) NRDsLive(ctx context.Context, params Params) (*SearchResult, error)
- func (c *Client) NSReverse(ctx context.Context, ns string, params Params) (*NSReverseResult, error)
- func (c *Client) Object(ctx context.Context, path string, params Params) (map[string]any, error)
- func (c *Client) Paginate(ctx context.Context, resource string, params Params, fn func(Domain) bool) error
- func (c *Client) Registrar(ctx context.Context, query string) (map[string]any, error)
- func (c *Client) RequestRaw(ctx context.Context, path string, params Params) ([]byte, http.Header, error)
- func (c *Client) Safety(ctx context.Context, domain string) (map[string]any, error)
- func (c *Client) SearchStatus(ctx context.Context) (map[string]any, error)
- func (c *Client) StatusGuide(ctx context.Context, query string) (map[string]any, error)
- func (c *Client) TLDCheck(ctx context.Context, prefix string, params Params) (map[string]any, error)
- func (c *Client) TLDTrends(ctx context.Context, trendType string, params Params) ([]map[string]any, error)
- func (c *Client) Typosquat(ctx context.Context, domain string, params Params) (*ListResult, error)
- func (c *Client) Usage(ctx context.Context) (map[string]any, error)
- func (c *Client) Whois(ctx context.Context, domain string) (map[string]any, error)
- type Domain
- type ListResult
- type NSDomain
- type NSReverseResult
- type Params
- type RateLimit
- type SearchResult
Constants ¶
const ( DefaultBaseURL = "https://premium-api.domainkits.com/api/v1" MaxLimit = 500 )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
func (*Client) CTSubdomains ¶
func (*Client) KeywordTrends ¶
func (*Client) MonitorChanges ¶
func (*Client) NRDsDownload ¶
func (*Client) RequestRaw ¶
func (*Client) SearchStatus ¶
func (*Client) StatusGuide ¶
type Domain ¶
type Domain struct {
Domain string `json:"domain"`
TLD string `json:"tld,omitempty"`
Created string `json:"created,omitempty"`
Expires string `json:"expires,omitempty"`
Period int `json:"period,omitempty"`
Age int `json:"age,omitempty"`
Length int `json:"length,omitempty"`
Components []string `json:"components,omitempty"`
ForSale string `json:"for_sale,omitempty"`
Platform string `json:"platform,omitempty"`
ListedDays *int `json:"listed_days,omitempty"`
Status string `json:"status,omitempty"`
AuctionDate string `json:"auction_date,omitempty"`
FoundDate string `json:"found_date,omitempty"`
Category string `json:"category,omitempty"`
Majestic *int `json:"majestic,omitempty"`
Backlinks *int `json:"backlinks,omitempty"`
Hold string `json:"hold,omitempty"`
RegYear string `json:"reg_year,omitempty"`
ExpYear string `json:"exp_year,omitempty"`
TLDCount int `json:"tld_count,omitempty"`
}
Domain is the union of the record fields the search endpoints return. Each endpoint fills its own fixed subset; unfilled fields stay zero.
type ListResult ¶
type NSDomain ¶ added in v0.3.5
type NSDomain struct {
Domain string `json:"domain"`
TLD string `json:"tld"`
Length int `json:"length"`
}
NSDomain is one row of the reverse nameserver lookup.
type NSReverseResult ¶ added in v0.3.5
NSReverseResult carries the rows plus the two counts the endpoint reports: Total is the match count after filters, NSTotal the domains on the nameserver before filters.
type SearchResult ¶
Click to show internal directories.
Click to hide internal directories.